#!/usr/bin/perl



######################################################
#
#	Before running this script, replace the values for the following variables
#	with information from the image used in your image map. Alternatively,
#	place the information in lines 5-7 of the file this script generates.
#
######################################################

$Image = "IMAGESOURCE";
$ImageHeight = "IMAGEHEIGHT";
$ImageWidth ="IMAGEWIDTH";

######################################################
#
#	Run this script from the command line like so
#	
#		./imagemap.pl SOURCEFILE
#
#	replacing SOURCEFILE with the name of the file containing your image map.
#
#	This script will then generate a new file with the name
#	
#		TIMESTAMP.html
#		
#	and attempt to open it. You should test this script with the sample source
#	file ("sample_source.html") included with this script.
#
#	Once you have run this script, open (a copy of) the source file, and
#	replace the original <img> tag and its associated image map with the entire
#	contents of the file generated by this script.
#
#	The code this script generates has been tested in MSIE 7, Safari 3.2.1,
#	and Firefox 3.0.4.
#
#	This script only handles one source file at at time, and it expects
#	an image map with <area> tags with the generalized form
#
#		<area shape="[SHAPE]" coords="[COORDINATES]" href="[URL]" />
#
#	If you would like to customize the <a> tags this script generates,
#	consider uncommenting lines 66 and 67 below by removing the # at the front
#	of each line. If you do so, the variables
#	$href_addendum and $custom_attributes will be added to each <a> tag like
#	so
#  
#		<a id="rectangle_XX" href="link$href_addendum" $custom_attributes />
#		                               ^^^^^^^^^^^^^^  ^^^^^^^^^^^^^^^^^^
#	Keep in mind that some special characters, such as ', should be escaped.
#	with a \.
#
#	I assume no liability for anything you might do with this code. While this
#	code takes care not to alter the source file it receives, you should make
#	backups of any files you process with this code.
#
#	I hope you find this script useful.
#
#	                                       Johnnie Wilcox
#	                                       code.net@mistersquid.com
#	
######################################################

#$href_addendum = '?PASSED_ATTRIBUTE1=VALUE1&amp;PASSED_ATTRIBUTE2=VALUE2&amp;HEIGHT=480&amp;WIDTH=600';
#$custom_attributes = 'class="CUSTOMCLASS"';

use POSIX qw(strftime);

$now_string = strftime("%Y%m%d%H%OM%OS",localtime(time));

local $/; # Slurp mode

$input = shift(@ARGV);

open (SOURCE, $input);

while (<SOURCE>) {

	$file = $_;

}

@lines = split(/\n/, $file);

open (TARGET, ">" . $now_string . "@_.html");

print TARGET <<endCSShead;
<style type="text/css">

#CSSImageMap
{
	background-image: url($Image);
	height: $ImageHeight\px;
	width: $ImageWidth\px;
	position:relative;
}

#CSSImageMap #ImageMapLinks a
{
	position:absolute;
}

#CSSImageMap #ImageMapLinks a span
{
	visibility:hidden;
}

#ImageMapLinks a.thickbox:hover
{
	border: 1px solid #83CBFF;
}

endCSShead

foreach $line (@lines) {
	if ( $line =~ /<area/ ) {
		$i++;
		$left = $line;
		$top = $line;
		$right = $line;
		$bottom = $line;

		$left =~ s/^.*?coords="(\d+).*\Z/\1/;
		$top =~ s/^.*?coords="\d+,(\d+).*\Z/\1/;
		$right =~ s/^.*?coords="\d+,\d+,(\d+).*\Z/\1/;
		$bottom =~ s/^.*?coords="\d+,\d+,\d+,(\d+).*\Z/\1/;

		$width = $right - $left;
		$height = $bottom - $top;
		
		$line =~ s/^\s+<area shape="[^"]+?"\s+?coords="[^"]+?" /<a id="rectangle_$i" /;
		$line =~ s/href="([^"]+?)"[^>]+?>/href="\1$href_addendum" $custom_attributes \/>/;
		$links[$i] = "\t\t" . $line . "\n";
		
		print TARGET <<endAnchorStyle;
#ImageMapLinks a\#rectangle_$i
{
	top: $top\px;
	left: $left\px;
	width: $width\px;
	height: $height\px;
}

endAnchorStyle
	}
}

print TARGET "</style>\n\n";

print TARGET <<openImageMapLinks;
<div id="CSSImageMap">
	<div id="ImageMapLinks">
openImageMapLinks
print TARGET @links;
print TARGET <<closeImageMapLinks;
	</div>
</div>
closeImageMapLinks
	
close TARGET || die "Cannot close $file: $!\n";
system ( "open " . $now_string . "'@_.html'" );